#!/bin/bash

# We're going to run this in the MacTeX working directory...
WORK=`pwd`

export COPYFILE_DISABLE=true

if [[ -d x86_64-darwin ]]; then
	rm -R x86_64-darwin
fi

mkdir x86_64-darwin


cd RawCode/x86_64-apple-darwin17.7.0
files=`ls`
for file in $files; do
	if [[ -L $file ]]; then
 		cp -R $file ../../x86_64-darwin/$file
	else
		cp $file ../../x86_64-darwin/$file
	fi
done
cd ../../

if [[ -e RawCode/asy ]]; then

	cp RawCode/asy  x86_64-darwin/asy

	cd x86_64-darwin
	ln -s ../../texmf-dist/asymptote/GUI/xasy.py xasy
	cd ..
	
fi


# The next section is about xindy. In 2011, the xindy.mem and xindy.run files from compiling do not
# work due to unexplained problems in CLisp. However, the 2010 versions of these files do work
# and the files are unchanged. So following advice from Joachim Schrod, we use 2010 versions
#
# Herbert Shultz pointed out the the 2010 version of xindy.run is 32 bits. Luckily, the 2017 versions,
# compiled with old CLisp, work (xindy.mem and xindy.run are paired and must come from the same compile).
# Also the 2017 xindy.run is 64 bits. 

if [[ -e x86_64-darwin/xindy.mem ]]; then
	rm x86_64-darwin/xindy.mem
fi

if [[ -e x86_64-darwin/xindy.run ]]; then
	rm x86_64-darwin/xindy.run
fi

cp xindy-2017/x86_64-darwin/xindy.mem x86_64-darwin/xindy.mem
cp xindy-2017/x86_64-darwin/xindy.run x86_64-darwin/xindy.run




cd x86_64-darwin
chgrp wheel *




# tlpkg/installer/lz4, wget, xz
# biber

files=`ls`
for f in $files; do
	if ! [[ -L $f ]] &&  [[ "$(file $f)" = "$f: Mach-O 64-bit executable x86_64" ]]; then
		codesign -s   "Developer ID Application: Richard Koch" --force --timestamp --options=runtime $f
	fi
done

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/gs-X11.entitlements  mf

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/gs-X11.entitlements  xdvi-xaw

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/gs-X11.entitlements  dvisvgm

# Fix luatex entitlements

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/luahbtex.entitlements  luahbtex

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/luahbtex.entitlements  luajithbtex

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/luahbtex.entitlements  luatex

codesign -s   "Developer ID Application: Richard Koch"  --force --timestamp --options=runtime --entitlements=${WORK}/luahbtex.entitlements  luajittex

cd ..

(cd  x86_64-darwin; tar cf - . ) > x86_64-darwin.tar

../xz --compress x86_64-darwin.tar


